@@ -29,6 +29,7 @@ our @EXPORT_OK = qw(
     detract
     detract_deep
     load
+    throw
     type_array
     type_code
     type_float
@@ -43,11 +44,13 @@ our @EXPORT_OK = qw(
 );
 
 our %EXPORT_TAGS = (
+    all  => [@EXPORT_OK],
+    core => [qw(deduce deduce_deep detract detract_deep load throw)],
     data => [grep m/data_/, @EXPORT_OK],
     type => [grep m/type_/, @EXPORT_OK],
 );
 
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 sub new {
     shift and goto &deduce_deep;
@@ -82,6 +85,11 @@ sub load ($) {
     return $class;
 }
 
+sub throw (@) {
+    unshift @_, my $class = load 'Data::Object::Exception';
+    goto $class->can('throw');
+}
+
 sub data_array ($) {
     unshift @_, my $class = load 'Data::Object::Array';
     goto $class->can('new');
@@ -328,7 +336,7 @@ Data::Object - Data Type Objects for Perl 5
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -346,6 +354,19 @@ objects which provide common methods for operating on the data.
 
 =head1 EXPORTS
 
+=head2 all
+
+    use Data::Object qw(:all);
+
+The all export tag will export all exportable functions.
+
+=head2 core
+
+    use Data::Object qw(:core);
+
+The core export tag will export the exportable functions C<deduce>,
+C<deduce_deep>, C<detract>, C<detract_deep>, C<load>, and C<throw> exclusively.
+
 =head2 data
 
     use Data::Object qw(:data);
@@ -487,15 +508,6 @@ The data_universal function returns a L<Data::Object::Universal> instance which
 wraps the provided data type and can be used to perform operations on the data.
 The C<type_universal> function is an alias to this function.
 
-=head2 load
-
-    # given 'List::Util';
-
-    $package = load 'List::Util'; # List::Util if loaded
-
-The load function attempts to dynamically load a module and either dies or
-returns the package name of the loaded module.
-
 =head2 deduce
 
     # given qr/\w+/;
@@ -562,6 +574,24 @@ is complex, this function traverses the data converting all nested data type
 objects into native values using the objects underlying reference. Note:
 Blessed objects are not traversed.
 
+=head2 load
+
+    # given 'List::Util';
+
+    $package = load 'List::Util'; # List::Util if loaded
+
+The load function attempts to dynamically load a module and either dies or
+returns the package name of the loaded module.
+
+=head2 throw
+
+    # given $message;
+
+    throw $message; # An exception (...) was thrown in -e at line 1
+
+The throw function will dynamically load and throw an exception object. This
+function takes all arguments accepted by the L<Data::Object::Exception> class.
+
 =head1 SEE ALSO
 
 =over 4
@@ -614,6 +644,14 @@ L<Data::Object::Universal>
 
 L<Data::Object::Autobox>
 
+=item *
+
+L<Data::Object::Library>
+
+=item *
+
+L<Data::Object::Signatures>
+
 =back
 
 =head1 AUTHOR
