@@ -10,7 +10,7 @@ use Data::Object::Class 'with';
 
 with 'Data::Object::Role::Hash';
 
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 sub new {
     my $class = shift;
@@ -213,7 +213,7 @@ Data::Object::Hash - A Hash Object for Perl 5
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -614,6 +614,14 @@ L<Data::Object::Universal>
 
 L<Data::Object::Autobox>
 
+=item *
+
+L<Data::Object::Library>
+
+=item *
+
+L<Data::Object::Signatures>
+
 =back
 
 =head1 AUTHOR
