@@ -17,7 +17,7 @@ use overload (
     fallback => 1,
 );
 
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 sub new {
     my $class = shift;
@@ -195,7 +195,7 @@ Data::Object::Number - A Number Object for Perl 5
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -529,6 +529,14 @@ L<Data::Object::Universal>
 
 L<Data::Object::Autobox>
 
+=item *
+
+L<Data::Object::Library>
+
+=item *
+
+L<Data::Object::Signatures>
+
 =back
 
 =head1 AUTHOR
