@@ -12,7 +12,7 @@ use Data::Object::Regexp::Result;
 
 with 'Data::Object::Role::Regexp';
 
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 sub new {
     my $class = shift;
@@ -63,7 +63,7 @@ Data::Object::Regexp - A Regexp Object for Perl 5
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -161,6 +161,14 @@ L<Data::Object::Universal>
 
 L<Data::Object::Autobox>
 
+=item *
+
+L<Data::Object::Library>
+
+=item *
+
+L<Data::Object::Signatures>
+
 =back
 
 =head1 AUTHOR
