@@ -12,7 +12,7 @@ map with($_), our @ROLES = qw(
     Data::Object::Role::Type
 );
 
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 sub abs {
     my ($number) = @_;
@@ -98,7 +98,7 @@ Data::Object::Role::Number - A Number Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -185,6 +185,14 @@ L<Data::Object::Role::Universal>
 
 L<Data::Object::Autobox>
 
+=item *
+
+L<Data::Object::Library>
+
+=item *
+
+L<Data::Object::Signatures>
+
 =back
 
 =head1 AUTHOR
