@@ -14,7 +14,7 @@ map with($_), our @ROLES = qw(
     Data::Object::Role::Type
 );
 
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 sub search {
     my($self, $string, $flags) = @_;
@@ -66,7 +66,7 @@ Data::Object::Role::Regexp - A Regexp Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -153,6 +153,14 @@ L<Data::Object::Role::Universal>
 
 L<Data::Object::Autobox>
 
+=item *
+
+L<Data::Object::Library>
+
+=item *
+
+L<Data::Object::Signatures>
+
 =back
 
 =head1 AUTHOR
