@@ -13,7 +13,7 @@ map with($_), our @ROLES = qw(
     Data::Object::Role::Type
 );
 
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 1;
 
@@ -29,7 +29,7 @@ Data::Object::Role::Universal - A Universal Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -120,6 +120,14 @@ L<Data::Object::Role::Universal>
 
 L<Data::Object::Autobox>
 
+=item *
+
+L<Data::Object::Library>
+
+=item *
+
+L<Data::Object::Signatures>
+
 =back
 
 =head1 AUTHOR
