@@ -4,7 +4,7 @@ package Data::Object::Singleton;
 use 5.010;
 use Data::Object::Class ();
 
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 sub import {
     my $target = caller;
@@ -16,17 +16,11 @@ sub import {
     my $hold;
 
     if (my $orig = $class->can('new')) {
-        no strict 'refs';
-        *{"${target}::new"} = sub {
-            $hold //= $orig->(@_)
-        };
+        no strict 'refs'; *{"${target}::new"} = sub { $hold //= $orig->(@_) };
     }
 
     if (my $orig = $class->can('new') and !$class->can('renew')) {
-        no strict 'refs';
-        *{"${target}::renew"} = sub {
-            $hold = $orig->(@_)
-        };
+        no strict 'refs'; *{"${target}::renew"} = sub { $hold = $orig->(@_) };
     }
 
     return;
