@@ -17,7 +17,7 @@ use overload (
     fallback => 1,
 );
 
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 sub new {
     my $class = shift;
@@ -204,7 +204,7 @@ Data::Object::String - A String Object for Perl 5
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -595,6 +595,14 @@ L<Data::Object::Universal>
 
 L<Data::Object::Autobox>
 
+=item *
+
+L<Data::Object::Library>
+
+=item *
+
+L<Data::Object::Signatures>
+
 =back
 
 =head1 AUTHOR
