@@ -10,7 +10,7 @@ use Data::Object::Class 'with';
 
 with 'Data::Object::Role::Universal';
 
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 sub data {
     goto &detract;
@@ -34,7 +34,7 @@ Data::Object::Universal - A Universal Object for Perl 5
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -104,6 +104,14 @@ L<Data::Object::Universal>
 
 L<Data::Object::Autobox>
 
+=item *
+
+L<Data::Object::Library>
+
+=item *
+
+L<Data::Object::Signatures>
+
 =back
 
 =head1 AUTHOR
